@@ -12,17 +12,21 @@ load_ui <- function(id){
              wellPanel(
                div(style = "height: 650px",
                    h3("Table Metadata", class = "heading_style"),
-                   radioGroupButtons(ns("tfrmt_source"), label = NULL, choices = c("None", "Upload", "Example")),
-                   fluidRow(
-                     column(12,
-                            shinyjs::hidden(fileInput(ns("tfrmt_load"), buttonLabel = "Load JSON", label = NULL, accept = c(".json")))
+                   shinyjs::hidden(
+                     div(
+                     id = ns("tfrmt_opts"),
+                     radioGroupButtons(ns("tfrmt_source"), label = NULL, choices = c("None", "Upload", "Example")),
+                     fluidRow(
+                       column(12,
+                              shinyjs::hidden(fileInput(ns("tfrmt_load"), buttonLabel = "Load JSON", label = NULL, accept = c(".json")))
+                       )
+                     ),
+                     fluidRow(
+                       shinyjs::hidden(radioGroupButtons(ns("tfrmt_ex"),
+                                                         label = NULL,
+                                                         choices = c("demog","ae","efficacy")))
                      )
-                   ),
-                   fluidRow(
-                     shinyjs::hidden(radioGroupButtons(ns("tfrmt_ex"),
-                                                       label = NULL,
-                                                       choices = c("demog","ae","efficacy")))
-                   ),
+                   )),
                    fluidRow(
                      div(style = "height: 500px; overflow-y:auto; ",
                          shinycssloaders::withSpinner(
@@ -39,6 +43,9 @@ load_ui <- function(id){
              wellPanel(
                div(style = "height: 650px",
                    h3("Data", class = "heading_style"),
+                   shinyjs::hidden(
+                     div(
+                       id = ns("data_opts"),
                    radioGroupButtons(ns("data_source"), label = NULL,
                                      choices = c("Auto", "Upload", "Example"), selected = "Auto"),
                    fluidRow(
@@ -50,6 +57,8 @@ load_ui <- function(id){
                      conditionalPanel("input.data_source=='Example'",
                                       radioGroupButtons(ns("data_ex"), label = NULL, choices = c("demog","ae","labs","efficacy")),
                                       ns = ns)
+                   )
+                   )
                    ),
                    fluidRow(
                      div(style = "height: 550px;",
@@ -67,7 +76,7 @@ load_ui <- function(id){
   )
 }
 
-load_server <- function(id, mockmode){
+load_server <- function(id, tfrmt_in = reactive(NULL), data_in = reactive(NULL), mockmode){
 
     moduleServer(
       id,
@@ -75,6 +84,10 @@ load_server <- function(id, mockmode){
 
         ns <- session$ns
 
+        observe({
+          shinyjs::toggle("tfrmt_opts", condition = is.null(tfrmt_in()))
+          shinyjs::toggle("data_opts", condition = is.null(data_in()))
+        })
         observe({
           shinyjs::toggle("tfrmt_load", condition = input$tfrmt_source=="Upload")
           shinyjs::toggle("tfrmt_ex", condition = input$tfrmt_source=="Example")
@@ -122,10 +135,12 @@ load_server <- function(id, mockmode){
 
         })
 
+
         # tfrmt to be used in the app
         tfrmt_out <- reactive({
-
-          if (input$tfrmt_source=="None"){
+          if (!is.null(tfrmt_in())){
+            tfrmt_in()
+          } else if (input$tfrmt_source=="None"){
             prep_tfrmt_app(tfrmt())
           }  else if (input$tfrmt_source=="Example"){
             tfrmt_ex()
@@ -147,10 +162,10 @@ load_server <- function(id, mockmode){
         # keep track of mode for downstream functionality
         mode <- reactive({
           if (mockmode() == TRUE){
-            if (input$data_source=="Auto"){
-              "mock_no_data"
-            } else {
+            if (!is.null(data_in()) || !input$data_source=="Auto"){
               "mock_with_data"
+            } else {
+              "mock_no_data"
             }
           } else if (mockmode() == FALSE){
             "reporting"
@@ -160,7 +175,9 @@ load_server <- function(id, mockmode){
         # data to be used in the app
         data_out <- reactive({
 
-          if (mockmode()==TRUE && input$data_source=="Auto"){
+          if (!is.null(data_in())){
+            data_in()
+          } else if (mockmode()==TRUE && input$data_source=="Auto"){
             NULL
           } else if (input$data_source=="Example"){
             data_ex()
