@@ -1,5 +1,8 @@
 #' Run tfrmt Builder Shiny App
 #'
+#' @param tfrmt tfrmt object to be loaded into app from R session. Defaults to `NULL`
+#' @param data data frame to be loaded into app from R session. Defaults to `NULL`
+#' @param mockmode Whether to initialize the app in mock mode. Defaults to `TRUE`
 #' @param run Boolean for whether the created object should be run directly. Set to `FALSE` for deployment
 #' @export
 #' @return Shiny app for creating and modifying tfrmt objects
@@ -7,11 +10,11 @@
 #' if (interactive()){
 #'   tfrmtbuilder()
 #' }
-tfrmtbuilder <- function(run = TRUE){
+tfrmtbuilder <- function(tfrmt = NULL, data = NULL, mockmode = TRUE, run = TRUE){
   app <- shinyApp(
-    ui =  tfrmtbuilder_ui("tb"),
+    ui =  tfrmtbuilder_ui("tb", mockmode),
     server = function(input,output,session){
-      tfrmtbuilder_server("tb")
+      tfrmtbuilder_server("tb", tfrmt, data)
       session$onSessionEnded(function() {
         stopApp()
       })
