@@ -2,8 +2,8 @@ test_that("End to end with mock/auto mode (no data)", {
 
   skip_if_not(interactive())
 
-  tfrmtbuilder_app <- tfrmtbuilder(run = FALSE)
-  app <- shinytest2::AppDriver$new(tfrmtbuilder_app)
+  app_dir <- rprojroot::find_testthat_root_file("e2e")
+  app <- shinytest2::AppDriver$new(app_dir)
 
   # click export tab
   app$set_inputs(`tb-all_tabs` = "Export")
@@ -12,7 +12,7 @@ test_that("End to end with mock/auto mode (no data)", {
   expect_snapshot_file("tfrmt_save.json")
 
   app$get_download("tb-export-tbl_save_png", filename = "tfrmt_save.png")
-  expect_snapshot_file("tfrmt_save.png")
+  expect_true(file.exists("tfrmt_save.png"))
 
   file.remove("tfrmt_save.json")
   file.remove("tfrmt_save.png")
